package com.example.venue_reservation_service.controller;

import com.example.venue_reservation_service.domain.User;
import com.example.venue_reservation_service.dto.AdminSlot;
import com.example.venue_reservation_service.dto.PointDTO;
import com.example.venue_reservation_service.service.AdminService;
import com.example.venue_reservation_service.vo.Result;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import jakarta.annotation.Resource;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping("/admin")
@CrossOrigin
@Api("管理员接口")
public class AdminController {

    @Resource
    private AdminService adminService;

    @ApiOperation("查询管理的场馆")
    @GetMapping("/query")
    public Result query(@RequestParam("userId") Integer userId){
        return adminService.queryVenue(userId);
    }

    @ApiOperation("管理员添加场地禁用时间")
    @PostMapping("/time")
    public Result time(@RequestBody AdminSlot slot){
        return adminService.addTime(slot);
    }

    @ApiOperation("通过手机号查询用户")
    @GetMapping("/select")
    public Result select(@RequestParam("phone") String phone){
        return adminService.selectUser(phone);
    }

    @ApiOperation("管理员为用户账号充值积分")
    @PostMapping("/point")
    public Result point(@RequestBody PointDTO dto){
        return adminService.userPoint(dto);
    }

    @ApiOperation("管理员绑定关联场馆")
    @PostMapping("/manage")
    public Result manage(@RequestParam("userId") Integer userId,
                         @RequestParam("typeId") Integer typeId){
        return adminService.manage(userId, typeId);
    }

    @ApiOperation("移除关联场馆信息")
    @PostMapping("/cancel")
    public Result cancel(@RequestParam("userId") Integer userId,
                         @RequestParam("typeId") Integer typeId){
        return adminService.cancel(userId, typeId);
    }

}
