package com.example.venue_reservation_service.service.impl;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.extension.toolkit.Db;
import com.example.venue_reservation_service.domain.Question;
import com.example.venue_reservation_service.domain.Reply;
import com.example.venue_reservation_service.dto.ReplyDTO;
import com.example.venue_reservation_service.service.ReplyService;
import com.example.venue_reservation_service.mapper.ReplyMapper;
import com.example.venue_reservation_service.vo.Result;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.Objects;

/**
* @author 31586
* @description 针对表【venue_reply(回复记录表)】的数据库操作Service实现
* @createDate 2025-06-21 14:15:36
*/
@Service
public class ReplyServiceImpl extends ServiceImpl<ReplyMapper, Reply>
    implements ReplyService{

    @Override
    public Result createReply(ReplyDTO dto) {
        String content = dto.getContent().trim();
        if (content.isEmpty()) {
            return Result.fail("回复内容不能为空");
        }
        Reply reply = new Reply();
        BeanUtils.copyProperties(dto, reply);
        reply.setCreatedTime(LocalDateTime.now());
        reply.setUpdatedTime(LocalDateTime.now());
        save(reply);

        Db.lambdaUpdate(Question.class)
                .set(Question::getStatus, 1)
                .eq(Question::getId, dto.getQuestionId())
                .update();

        return Result.ok().message("保存回复成功");
    }

    @Override
    public Result updateReply( ReplyDTO dto) {
        String content = dto.getContent().trim();
        if (content.isEmpty()) {
            return Result.fail("回复内容不能为空");
        }

        String oldContent = lambdaQuery()
                .eq(Reply::getQuestionId, dto.getQuestionId())
                .eq(Reply::getAdminId, dto.getAdminId())
                .one().getContent();

        if(Objects.equals(oldContent, content)) {
            return Result.fail().message("回复内容未修改");
        }

        lambdaUpdate()
                .set(Reply::getContent, content)
                .set(Reply::getUpdatedTime, LocalDateTime.now())
                .eq(Reply::getQuestionId, dto.getQuestionId())
                .eq(Reply::getAdminId, dto.getAdminId())
                .update();


        return Result.ok().message("保存回复成功");

    }
}




